@@ -24,9 +24,7 @@ import org.gradle.internal.classpath.DefaultClassPath;
 
 import java.util.Arrays;
 
-import static org.gradle.api.internal.artifacts.dsl.dependencies.DependencyFactory.ClassPathNotation.GRADLE_API;
-import static org.gradle.api.internal.artifacts.dsl.dependencies.DependencyFactory.ClassPathNotation.LOCAL_GROOVY;
-import static org.gradle.api.internal.artifacts.dsl.dependencies.DependencyFactory.ClassPathNotation.GRADLE_TEST_KIT;
+import static org.gradle.api.internal.artifacts.dsl.dependencies.DependencyFactory.ClassPathNotation.*;
 
 public class DependencyClassPathProvider implements ClassPathProvider {
     private final ModuleRegistry moduleRegistry;
@@ -38,7 +36,7 @@ public class DependencyClassPathProvider implements ClassPathProvider {
     }
 
     public ClassPath findClassPath(String name) {
-        if (name.equals(GRADLE_API.name())) {
+        if (name.equals(GRADLE_API.name()) || name.equals(FAT_GRADLE_API.name())) {
             ClassPath classpath = new DefaultClassPath();
             for (String moduleName : Arrays.asList("gradle-core", "gradle-dependency-management", "gradle-plugin-use", "gradle-tooling-api")) {
                 for (Module module : moduleRegistry.getModule(moduleName).getAllRequiredModules()) {
@@ -51,16 +49,14 @@ public class DependencyClassPathProvider implements ClassPathProvider {
             return classpath;
         }
         if (name.equals(GRADLE_TEST_KIT.name())) {
-            ClassPath classpath = new DefaultClassPath();
-            for (Module module : moduleRegistry.getModule("gradle-test-kit").getAllRequiredModules()) {
-                classpath = classpath.plus(module.getClasspath());
-            }
-            return classpath;
+            return moduleRegistry.getModule("gradle-test-kit").getImplementationClasspath();
+        }
+        if (name.equals(FAT_GRADLE_TEST_KIT.name())) {
+            return moduleRegistry.getModule("gradle-test-kit").getClasspath();
         }
         if (name.equals(LOCAL_GROOVY.name())) {
             return moduleRegistry.getExternalModule("groovy-all").getClasspath();
         }
-
         return null;
     }
 }
