@@ -18,11 +18,17 @@ package org.gradle.tooling.internal.consumer.parameters;
 import com.google.common.collect.Lists;
 import org.gradle.api.GradleException;
 import org.gradle.initialization.BuildCancellationToken;
+import org.gradle.internal.classpath.ClassPath;
+import org.gradle.internal.composite.GradleParticipantBuild;
 import org.gradle.tooling.CancellationToken;
+import org.gradle.tooling.internal.connection.DefaultBuildIdentifier;
+import org.gradle.tooling.model.BuildIdentifier;
 import org.gradle.tooling.events.ProgressListener;
 import org.gradle.tooling.internal.adapter.ProtocolToModelAdapter;
 import org.gradle.tooling.internal.consumer.CancellationTokenInternal;
+import org.gradle.tooling.internal.consumer.CompositeConnectionParameters;
 import org.gradle.tooling.internal.consumer.ConnectionParameters;
+import org.gradle.tooling.internal.consumer.ProjectConnectionParameters;
 import org.gradle.tooling.internal.gradle.TaskListingLaunchable;
 import org.gradle.tooling.internal.protocol.*;
 import org.gradle.tooling.model.Launchable;
@@ -60,6 +66,8 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
         private List<String> arguments;
         private List<String> tasks;
         private List<InternalLaunchable> launchables;
+        private ClassPath injectedPluginClasspath = ClassPath.EMPTY;
+        private BuildIdentifier buildIdentifier;
 
         private Builder() {
         }
@@ -134,11 +142,17 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
                         + (launchable != null ? launchable.getClass() : "null"));
                 }
             }
-            this.launchables = launchablesParams;
+            // Tasks are ignored by providers if launchables is not null
+            this.launchables = launchablesParams.isEmpty() ? null : launchablesParams;
             tasks = Lists.newArrayList(taskPaths);
             return this;
         }
 
+        public Builder setInjectedPluginClasspath(ClassPath classPath) {
+            this.injectedPluginClasspath = classPath;
+            return this;
+        }
+
         public void addProgressListener(org.gradle.tooling.ProgressListener listener) {
             legacyProgressListeners.add(listener);
         }
@@ -159,19 +173,41 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
             this.cancellationToken = cancellationToken;
         }
 
+        public Builder setRootDirectory(File rootDirectory) {
+            this.buildIdentifier = new DefaultBuildIdentifier(rootDirectory);
+            return this;
+        }
+
+        public Builder setBuildIdentifier(BuildIdentifier buildIdentifier) {
+            this.buildIdentifier = buildIdentifier;
+            return this;
+        }
+
         public ConsumerOperationParameters build() {
             if (entryPoint == null) {
                 throw new IllegalStateException("No entry point specified.");
             }
 
-            // create the listener adapters right when the ConsumerOperationParameters are instantiated but no earlier,
-            // this ensures that when multiple requests are issued that are built from the same builder, such requests do not share any state kept in the listener adapters
-            // e.g. if the listener adapters do per-request caching, such caching must not leak between different requests built from the same builder
-            ProgressListenerAdapter progressListenerAdapter = new ProgressListenerAdapter(this.legacyProgressListeners);
-            FailsafeBuildProgressListenerAdapter buildProgressListenerAdapter = new FailsafeBuildProgressListenerAdapter(
-                    new BuildProgressListenerAdapter(this.testProgressListeners, this.taskProgressListeners, this.buildOperationProgressListeners));
-            return new ConsumerOperationParameters(entryPoint, parameters, stdout, stderr, colorOutput, stdin, javaHome, jvmArguments, arguments, tasks, launchables,
-                    progressListenerAdapter, buildProgressListenerAdapter, cancellationToken);
+            return new ConsumerOperationParameters(entryPoint, parameters, stdout, stderr, colorOutput, stdin, javaHome, jvmArguments, arguments, tasks, launchables, injectedPluginClasspath,
+                legacyProgressListeners, testProgressListeners, taskProgressListeners, buildOperationProgressListeners, cancellationToken, buildIdentifier);
+        }
+
+        public void copyFrom(ConsumerOperationParameters operationParameters) {
+            tasks = operationParameters.tasks;
+            launchables = operationParameters.launchables;
+            cancellationToken = operationParameters.cancellationToken;
+            legacyProgressListeners.addAll(operationParameters.legacyProgressListeners);
+            taskProgressListeners.addAll(operationParameters.taskProgressListeners);
+            testProgressListeners.addAll(operationParameters.testProgressListeners);
+            buildOperationProgressListeners.addAll(operationParameters.buildOperationProgressListeners);
+            arguments = operationParameters.arguments;
+            jvmArguments = operationParameters.jvmArguments;
+            stdout = operationParameters.stdout;
+            stderr = operationParameters.stderr;
+            stdin = operationParameters.stdin;
+            colorOutput = operationParameters.colorOutput;
+            javaHome = operationParameters.javaHome;
+            injectedPluginClasspath = operationParameters.injectedPluginClasspath;
         }
     }
 
@@ -192,10 +228,18 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
     private final List<String> arguments;
     private final List<String> tasks;
     private final List<InternalLaunchable> launchables;
+    private final ClassPath injectedPluginClasspath;
+    private final BuildIdentifier buildIdentifier;
+
+    private final List<org.gradle.tooling.ProgressListener> legacyProgressListeners;
+    private final List<ProgressListener> testProgressListeners;
+    private final List<ProgressListener> taskProgressListeners;
+    private final List<ProgressListener> buildOperationProgressListeners;
 
     private ConsumerOperationParameters(String entryPointName, ConnectionParameters parameters, OutputStream stdout, OutputStream stderr, Boolean colorOutput, InputStream stdin,
-                                        File javaHome, List<String> jvmArguments, List<String> arguments, List<String> tasks, List<InternalLaunchable> launchables,
-                                        ProgressListenerAdapter progressListener, FailsafeBuildProgressListenerAdapter buildProgressListener, CancellationToken cancellationToken) {
+                                        File javaHome, List<String> jvmArguments, List<String> arguments, List<String> tasks, List<InternalLaunchable> launchables, ClassPath injectedPluginClasspath,
+                                        List<org.gradle.tooling.ProgressListener> legacyProgressListeners, List<ProgressListener> testProgressListeners, List<ProgressListener> taskProgressListeners,
+                                        List<ProgressListener> buildOperationProgressListeners, CancellationToken cancellationToken, BuildIdentifier buildIdentifier) {
         this.entryPointName = entryPointName;
         this.parameters = parameters;
         this.stdout = stdout;
@@ -207,9 +251,20 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
         this.arguments = arguments;
         this.tasks = tasks;
         this.launchables = launchables;
-        this.progressListener = progressListener;
-        this.buildProgressListener = buildProgressListener;
+        this.injectedPluginClasspath = injectedPluginClasspath;
         this.cancellationToken = cancellationToken;
+        this.buildIdentifier = buildIdentifier;
+        this.legacyProgressListeners = legacyProgressListeners;
+        this.testProgressListeners = testProgressListeners;
+        this.taskProgressListeners = taskProgressListeners;
+        this.buildOperationProgressListeners = buildOperationProgressListeners;
+
+        // create the listener adapters right when the ConsumerOperationParameters are instantiated but no earlier,
+        // this ensures that when multiple requests are issued that are built from the same builder, such requests do not share any state kept in the listener adapters
+        // e.g. if the listener adapters do per-request caching, such caching must not leak between different requests built from the same builder
+        this.progressListener = new ProgressListenerAdapter(this.legacyProgressListeners);
+        this.buildProgressListener = new FailsafeBuildProgressListenerAdapter(
+            new BuildProgressListenerAdapter(this.testProgressListeners, this.taskProgressListeners, this.buildOperationProgressListeners));
     }
 
     private static void validateJavaHome(File javaHome) {
@@ -225,6 +280,9 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
         return entryPointName;
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public long getStartTime() {
         return startTime;
     }
@@ -233,42 +291,72 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
         return parameters.getVerboseLogging();
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public File getGradleUserHomeDir() {
         return parameters.getGradleUserHomeDir();
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public File getProjectDir() {
-        return parameters.getProjectDir();
+        return parameters instanceof ProjectConnectionParameters ? ((ProjectConnectionParameters) parameters).getProjectDir() : null;
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public Boolean isSearchUpwards() {
-        return parameters.isSearchUpwards();
+        return parameters instanceof ProjectConnectionParameters ? ((ProjectConnectionParameters) parameters).isSearchUpwards() : Boolean.FALSE;
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public Boolean isEmbedded() {
         return parameters.isEmbedded();
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public TimeUnit getDaemonMaxIdleTimeUnits() {
         return parameters.getDaemonMaxIdleTimeUnits();
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public Integer getDaemonMaxIdleTimeValue() {
         return parameters.getDaemonMaxIdleTimeValue();
     }
 
+    /**
+     * @since 2.2-rc-1
+     */
     public File getDaemonBaseDir() {
         return parameters.getDaemonBaseDir();
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public OutputStream getStandardOutput() {
         return stdout;
     }
 
+    /**
+     * @since 1.0-milestone-3
+     */
     public OutputStream getStandardError() {
         return stderr;
     }
 
+    /**
+     * @since 2.3-rc-1
+     */
     public Boolean isColorOutput() {
         return colorOutput;
     }
@@ -293,14 +381,30 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
         return tasks;
     }
 
+    /**
+     * @since 1.12-rc-1
+     */
     public List<InternalLaunchable> getLaunchables() {
         return launchables;
     }
 
+    /**
+     * @since 2.8-rc-1
+     */
+    public List<File> getInjectedPluginClasspath() {
+        return injectedPluginClasspath.getAsFiles();
+    }
+
+    /**
+     * @since 1.0-milestone-3
+     */
     public ProgressListenerVersion1 getProgressListener() {
         return progressListener;
     }
 
+    /**
+     * @since 2.4-rc-1
+     */
     public FailsafeBuildProgressListenerAdapter getBuildProgressListener() {
         return buildProgressListener;
     }
@@ -308,4 +412,12 @@ public class ConsumerOperationParameters implements BuildOperationParametersVers
     public BuildCancellationToken getCancellationToken() {
         return ((CancellationTokenInternal) cancellationToken).getToken();
     }
+
+    public List<GradleParticipantBuild> getBuilds() {
+        return parameters instanceof CompositeConnectionParameters ? ((CompositeConnectionParameters) parameters).getBuilds() : null;
+    }
+
+    public BuildIdentifier getBuildIdentifier() {
+        return buildIdentifier;
+    }
 }
