@@ -29,9 +29,6 @@ import java.util.Map;
 import java.util.Set;
 import java.util.TreeSet;
 
-import org.springframework.boot.cli.command.OptionParsingCommand;
-import org.springframework.boot.cli.command.status.ExitStatus;
-
 import groovy.lang.Closure;
 import joptsimple.BuiltinHelpFormatter;
 import joptsimple.HelpFormatter;
@@ -40,6 +37,9 @@ import joptsimple.OptionParser;
 import joptsimple.OptionSet;
 import joptsimple.OptionSpecBuilder;
 
+import org.springframework.boot.cli.command.OptionParsingCommand;
+import org.springframework.boot.cli.command.status.ExitStatus;
+
 /**
  * Delegate used by {@link OptionParsingCommand} to parse options and run the command.
  *
@@ -87,7 +87,7 @@ public class OptionHandler {
 				argsToUse[i] = "--cp";
 			}
 		}
-		OptionSet options = getParser().parse(args);
+		OptionSet options = getParser().parse(argsToUse);
 		return run(options);
 	}
 
@@ -95,7 +95,7 @@ public class OptionHandler {
 	 * Run the command using the specified parsed {@link OptionSet}.
 	 * @param options the parsed option set
 	 * @return an ExitStatus
-	 * @throws Exception
+	 * @throws Exception in case of errors
 	 */
 	protected ExitStatus run(OptionSet options) throws Exception {
 		if (this.closure != null) {
@@ -180,7 +180,7 @@ public class OptionHandler {
 
 		private final String description;
 
-		public OptionHelpAdapter(OptionDescriptor descriptor) {
+		OptionHelpAdapter(OptionDescriptor descriptor) {
 			this.options = new LinkedHashSet<String>();
 			for (String option : descriptor.options()) {
 				this.options.add((option.length() == 1 ? "-" : "--") + option);
