@@ -20,11 +20,11 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
+import joptsimple.OptionSet;
+
 import org.springframework.boot.cli.util.ResourceUtils;
 import org.springframework.util.Assert;
 
-import joptsimple.OptionSet;
-
 /**
  * Extract source file options (anything following '--' in an {@link OptionSet}).
  *
@@ -96,7 +96,7 @@ public class SourceOptions {
 		}
 		this.args = Collections.unmodifiableList(
 				nonOptionArguments.subList(sourceArgCount, nonOptionArguments.size()));
-		Assert.isTrue(sources.size() > 0, "Please specify at least one file");
+		Assert.isTrue(!sources.isEmpty(), "Please specify at least one file");
 		this.sources = Collections.unmodifiableList(sources);
 	}
 
