@@ -1,5 +1,5 @@
 /*
- * Copyright 2012-2014 the original author or authors.
+ * Copyright 2012-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 
 package org.springframework.boot.cli.compiler.autoconfigure;
 
+import groovy.lang.GroovyClassLoader;
 import org.codehaus.groovy.ast.AnnotationNode;
 import org.codehaus.groovy.ast.ClassHelper;
 import org.codehaus.groovy.ast.ClassNode;
@@ -23,12 +24,11 @@ import org.codehaus.groovy.classgen.GeneratorContext;
 import org.codehaus.groovy.control.CompilationFailedException;
 import org.codehaus.groovy.control.SourceUnit;
 import org.codehaus.groovy.control.customizers.ImportCustomizer;
+
 import org.springframework.boot.cli.compiler.CompilerAutoConfiguration;
 import org.springframework.boot.cli.compiler.DependencyCustomizer;
 import org.springframework.boot.cli.compiler.GroovyCompilerConfiguration;
 
-import groovy.lang.GroovyClassLoader;
-
 /**
  * {@link CompilerAutoConfiguration} for Spring.
  *
@@ -63,13 +63,14 @@ public class SpringBootCompilerAutoConfiguration extends CompilerAutoConfigurati
 				"org.springframework.context.MessageSource",
 				"org.springframework.core.annotation.Order",
 				"org.springframework.core.io.ResourceLoader",
+				"org.springframework.boot.ApplicationRunner",
+				"org.springframework.boot.ApplicationArguments",
 				"org.springframework.boot.CommandLineRunner",
 				"org.springframework.boot.context.properties.ConfigurationProperties",
 				"org.springframework.boot.context.properties.EnableConfigurationProperties",
 				"org.springframework.boot.autoconfigure.EnableAutoConfiguration",
 				"org.springframework.boot.context.properties.ConfigurationProperties",
-				"org.springframework.boot.context.properties.EnableConfigurationProperties",
-				"org.springframework.boot.groovy.GrabMetadata");
+				"org.springframework.boot.context.properties.EnableConfigurationProperties");
 		imports.addStarImports("org.springframework.stereotype",
 				"org.springframework.scheduling.annotation");
 	}
