@@ -16,6 +16,7 @@
 
 package org.springframework.boot.cli.compiler.autoconfigure;
 
+import groovy.lang.GroovyClassLoader;
 import org.codehaus.groovy.ast.AnnotationNode;
 import org.codehaus.groovy.ast.ClassHelper;
 import org.codehaus.groovy.ast.ClassNode;
@@ -24,15 +25,14 @@ import org.codehaus.groovy.classgen.GeneratorContext;
 import org.codehaus.groovy.control.CompilationFailedException;
 import org.codehaus.groovy.control.SourceUnit;
 import org.codehaus.groovy.control.customizers.ImportCustomizer;
+
 import org.springframework.boot.cli.compiler.AstUtils;
 import org.springframework.boot.cli.compiler.CompilerAutoConfiguration;
 import org.springframework.boot.cli.compiler.DependencyCustomizer;
 import org.springframework.boot.cli.compiler.GroovyCompilerConfiguration;
 
-import groovy.lang.GroovyClassLoader;
-
 /**
- * {@link CompilerAutoConfiguration} for Spring Test
+ * {@link CompilerAutoConfiguration} for Spring Test.
  *
  * @author Dave Syer
  * @since 1.1.0
@@ -56,10 +56,10 @@ public class SpringTestCompilerAutoConfiguration extends CompilerAutoConfigurati
 			GeneratorContext generatorContext, SourceUnit source, ClassNode classNode)
 					throws CompilationFailedException {
 		if (!AstUtils.hasAtLeastOneAnnotation(classNode, "RunWith")) {
-			AnnotationNode runwith = new AnnotationNode(ClassHelper.make("RunWith"));
-			runwith.addMember("value",
+			AnnotationNode runWith = new AnnotationNode(ClassHelper.make("RunWith"));
+			runWith.addMember("value",
 					new ClassExpression(ClassHelper.make("SpringJUnit4ClassRunner")));
-			classNode.addAnnotation(runwith);
+			classNode.addAnnotation(runWith);
 		}
 	}
 
